==> linuxconf-1.19.src.tar.gz: linuxconf-1.19/modules/xterminals/xterminals.cc <==
/* ***********

	Check comments starting with // ### and fill appropriate code there

   ***********
*/
#pragma implementation
#include <stdio.h>
#include <string.h>
#include <translat.h>
#include "xterminals.h"
#include "xterminals.m"

MODULE_DEFINE_VERSION(xterminals);

PUBLIC MODULE_xterminals::MODULE_xterminals()
	: LINUXCONF_MODULE("xterminals")
{
	linuxconf_loadmsg ("xterminals",PACKAGE_REV);
}


static const char *keymenu=NULL;

PUBLIC void MODULE_xterminals::setmenu (
	DIALOG &dia,
	MENU_CONTEXT context)
{
	if (context == MENU_NETWORK_SERVER){
		keymenu = MSG_U(M_xterminals,"Xterminals manager");
		dia.new_menuitem ("xterminals","",keymenu);
	}
}

PUBLIC int MODULE_xterminals::domenu (
	MENU_CONTEXT context,
	const char *key)
{
	if (context == MENU_NETWORK_SERVER){
		if (key == keymenu){
			xterminals_edit();
		}
	}
	return 0;
}


PUBLIC int MODULE_xterminals::dohtml (const char *key)
{
	int ret = LNCF_NOT_APPLICABLE;
	if (strcmp(key,"xterminals")==0){
		// ### Insert any menu and dialog here
		ret = 0;
	}
	return ret;
}


static void usage()
{
	xconf_error (MSG_U(T_USAGE
		,"xterminals usage\n"
		 "\n"
		 "xterminals --option ...\n")
		);
}

PUBLIC int MODULE_xterminals::execmain (int argc , char *argv[])
{
	int ret = LNCF_NOT_APPLICABLE;
	const char *pt = strrchr(argv[0],'/');
	if (pt != NULL){
		pt++;
	}else{
		pt = argv[0];
	}
	if (strcmp(pt,"xterminals")==0){
		ret = -1;
		if (argc == 1){
			// ### Place call to main menu of the module
		}else{
			// ### Add some option parsing for the module
			::usage();
		}
	}
	return ret;
}


static MODULE_xterminals xterminals;

==> linuxconf-1.21.src.tar.gz: linuxconf-1.21/modules/xterminals/xterminals.cc <==
/* ***********

	Check comments starting with // ### and fill appropriate code there

   ***********
*/
#pragma implementation
#include <stdio.h>
#include <string.h>
#include <translat.h>
#include "xterminals.h"
#include "xterminals.m"

MODULE_DEFINE_VERSION(xterminals);

PUBLIC MODULE_xterminals::MODULE_xterminals()
	: LINUXCONF_MODULE("xterminals")
{
	linuxconf_loadmsg ("xterminals",PACKAGE_REV);
}


static const char *keymenu=NULL;

PUBLIC void MODULE_xterminals::setmenu (
	DIALOG &dia,
	MENU_CONTEXT context)
{
	if (context == MENU_NETWORK_SERVER){
		keymenu = MSG_U(M_xterminals,"Xterminals manager");
		dia.new_menuitem ("xterminals","",keymenu);
	}
}

PUBLIC int MODULE_xterminals::domenu (
	MENU_CONTEXT context,
	const char *key)
{
	if (context == MENU_NETWORK_SERVER){
		if (key == keymenu){
			xterminals_edit();
		}
	}
	return 0;
}


PUBLIC int MODULE_xterminals::dohtml (const char *key)
{
	int ret = LNCF_NOT_APPLICABLE;
	if (strcmp(key,"xterminals")==0){
		// ### Insert any menu and dialog here
		ret = 0;
	}
	return ret;
}


static void usage()
{
	xconf_error (MSG_U(T_USAGE
		,"xterminals usage\n"
		 "\n"
		 "xterminals --option ...\n")
		);
}

PUBLIC int MODULE_xterminals::execmain (int argc , char *argv[], bool)
{
	int ret = LNCF_NOT_APPLICABLE;
	const char *pt = strrchr(argv[0],'/');
	if (pt != NULL){
		pt++;
	}else{
		pt = argv[0];
	}
	if (strcmp(pt,"xterminals")==0){
		ret = -1;
		if (argc == 1){
			// ### Place call to main menu of the module
		}else{
			// ### Add some option parsing for the module
			::usage();
		}
	}
	return ret;
}


static MODULE_xterminals xterminals;
